@@ -20,12 +20,12 @@ def get_frame_cell_value_type(cell: Cell) -> FrameCellValueTypes:
 
 
 class FrameSheet(Sheet):
-    frame_elements: List[FrameElement] = list()
-
     def __init__(
             self,
             worksheet: Worksheet,
     ):
+        self.frame_elements: List[FrameElement] = list()
+
         super().__init__(
             worksheet=worksheet,
             end_of_sheet_rows_limit=20,
