@@ -5,7 +5,6 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
-from xlsx_lib.domain.distribution.distribution_data import DistributionData
 from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
 from xlsx_lib.domain.distribution.distribution_sheet import DistributionData, DistributionSheet
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
@@ -39,14 +38,14 @@ sheetnames_relationships = {
 
 
 class MotorcycleModelWorkbook:
-    motorcycle_model: Optional[MotorcycleModel]
-    new_distribution_images: Optional[List[NewDistributionImage]]
-
     def __init__(
             self,
             file: Union[BytesIO, str],
             filename: Optional[str],
     ):
+        self.motorcycle_model: Optional[MotorcycleModel]
+        self.new_distribution_images: Optional[List[NewDistributionImage]]
+
         workbook: Workbook = load_workbook(filename=file)
 
         model_name: str = filename[filename.rfind("/") + 1:filename.rfind(".")] \
